/*
 *
 * This source file belongs to the Sensoria CASE tool developed at the Institute of 
 * Computer Science, Programming and Software Engineering, of the Ludwig-Maximilians-
 * Universität München, Germany. 
 *
 * See the enclosed LICENSE file for licensing information.
 *
 */
package com.uppaal.verifyta.ws;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * A Debug File Handler
 * 
 * @version $Id: DebugFileHandler.java,v 1.1 2007/03/06 15:29:54 mayer Exp $
 * @author Max Zeumer
 *
 */
public class DebugFileHandler extends FileHandler {

	private static List<Integer> fileNumbers = new ArrayList<Integer>();
		
	private List<File> files = new ArrayList<File>();

	private String tmpFolderName;

	private boolean deleteFiles;

	public DebugFileHandler(String tmpFolderName, boolean deleteFiles){
		this.tmpFolderName = tmpFolderName;
		this.deleteFiles = deleteFiles;
	}
	
	@Override
	public File createFile(String base, String extension) throws IOException{
		// create a unique id to use as a filename
		// to avoid mix ups with parallel requests
		int fileNumber = 1;
		while (fileNumbers.contains(new Double(fileNumber))){
			fileNumber = (int)Math.random(); 
		}
		fileNumbers.add(new Integer(fileNumber));
		File file = new File(tmpFolderName+base+fileNumber+"."+extension);
		files.add(file);
		return file;
	}

	@Override
	public void deleteFiles() throws IOException{
		if (deleteFiles){
			for (File file: files){
				if (!file.delete()) throw new IOException("Deleting file "+ file.getAbsolutePath() + " failed. \n");
			}
		}
	}

}
