/*
 *
 * This source file belongs to the Sensoria CASE tool developed at the Institute of 
 * Computer Science, Programming and Software Engineering, of the Ludwig-Maximilians-
 * Universität München, Germany. 
 *
 * See the enclosed LICENSE file for licensing information.
 *
 */
package com.uppaal.verifyta.ws;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

/**
 * This is a convenience class for handling temp files. The file handling is
 * outsourced for the following reasons:
 * <ul>
 * <li>providing different implementations for debugging and real use, where in
 * debug mode the temp files should be persistent</li>
 * <li>For a real deployment of the service the files must be handled in such a
 * way that no file is used by more than one process</li>
 * </ul>
 * TODO: Consider synchronisation problems within the external tools.
 * 
 * @version $Id: FileHandler.java,v 1.1 2007/03/06 15:29:55 mayer Exp $
 * @author Max Zeumer
 */
abstract class FileHandler {

	/**
	 * Create a new file name{0..9}"."extension
	 * 
	 * @param properties The properties object
	 * @param base A base file name
	 * @param extension The file extension
	 * @return
	 */
	public abstract File createFile(String base, String extension) throws IOException;


	/**
	 * Delete all used temp files
	 * 
	 * @throws IOException
	 */
	public abstract void deleteFiles() throws IOException;

	public void writeToFile(String content, File file) throws IOException {
		new File(file.getParent()).mkdirs();
		file.createNewFile();
		FileWriter fileWriter= new FileWriter(file);
		fileWriter.write(content);
		fileWriter.flush();
	}
}
